/*****************************************************************************/
/*                                                                           */
/* UNIT: abs_spec  (Utility interface level library routine)                 */
/*                                                                           */
/* Author: Nikola Stojanovic                                                 */
/*                                                                           */
/* Revision:    17 DEC 94   Version 1.0                                      */
/*                                                                           */
/* Function:                                                                 */
/*                                                                           */
/*   Procedure interfaces user programs with the "ntl" library utilities;    */
/* determines new offset (relative to the new origin) of a position given    */
/* its absolute location within the alignment; fixes the path name for file  */
/* names needed by lower-level library routines; returns NULL if there were  */
/* no errors (and the list of corresponding offsets have been found), or     */
/* string containing an error message otherwise                              */
/*                                                                           */
/*****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include "ntl4.h"
#include "globin/globin_parm.h"         /* standard reference files */



/*****************************************************************************/
/*                                                                           */
/* Definitions section                                                       */
/*                                                                           */
/*****************************************************************************/


/*****************************************************************************/
/* Unit constants                                                            */
/*****************************************************************************/



/*****************************************************************************/
/*                                                                           */
/* Code section                                                              */
/*                                                                           */
/*****************************************************************************/

/*****************************************************************************/
/*                                                                           */
/* PROCEDURE: abs_spec                                                       */
/*                                                                           */
/* Central procedure for the unit; returns NULL if the alternative offset    */
/*   has been found and returned, diagnostic string otherwise                */

char *abs_spec (long int position, char *origin, appint_ptr *result)
{
 errind exec_status; char *error_report;

 if ((exec_status = NTL3_Abs_Spec (position, origin,
                                   globin_filename ("Origins"),
                                   globin_filename ("Default_Alignment"),
                                   result)) == NULL)
  return NULL;
 else {
  error_report = exec_status -> message; exec_status -> message = NULL;
  free (exec_status); return error_report;
 }
}

