/*****************************************************************************/
/*                                                                           */
/* UNIT: abs_corres_2  (Utility interface level library routine)             */
/*                                                                           */
/* Author: Nikola Stojanovic                                                 */
/*                                                                           */
/* Revision:    07 SEP 94   Version 1.0                                      */
/*                                                                           */
/* Function:                                                                 */
/*                                                                           */
/*   Procedure interfaces user programs with the "ntl" library utilities;    */
/* performs "absolute correspondence" determination for a pair of positions, */
/* given by the reference origin and a pair of offsets; fixes the path name  */
/* for file names needed by lower-level library routines; returns NULL if    */
/* there were no errors (and the list of corresponding offsets have been     */
/* found), or string containing an error message otherwise                   */
/*                                                                           */
/*****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include "ntl4.h"
#include "globin/globin_parm.h"         /* standard reference files */



/*****************************************************************************/
/*                                                                           */
/* Definitions section                                                       */
/*                                                                           */
/*****************************************************************************/


/*****************************************************************************/
/* Unit constants                                                            */
/*****************************************************************************/



/*****************************************************************************/
/*                                                                           */
/* Code section                                                              */
/*                                                                           */
/*****************************************************************************/

/*****************************************************************************/
/*                                                                           */
/* PROCEDURE: abs_corres_2                                                   */
/*                                                                           */
/* Execution of unit code; returns NULL if no errors at lower levels         */

char *abs_corres_2 (char *reference, long int offset_1, long int offset_2,
                    twoint_ptr *result)
{
 errind exec_status; char *error_report;

 if ((exec_status = NTL3_Abs_Corres_2 (reference, offset_1, offset_2,
                                       globin_filename ("Origins"),
                                       globin_filename ("Default_Alignment"),
                                       result)) == NULL) return NULL;
 else {
  error_report = exec_status -> message; exec_status -> message = NULL;
  free (exec_status); return error_report;
 }
}

